@@ -85,8 +85,8 @@ def get_subscribed_email_addresses(email):
       A list of strings: email addresses.
     """
     email_medium = get_medium()
-    if email.subentity_type is not None:
-        all_entities = list(email.send_to.get_sub_entities().is_any_type(email.subentity_type))
+    if email.subentity_kind is not None:
+        all_entities = [se for se in email.send_to.get_sub_entities() if se.entity_kind_id == email.subentity_kind_id]
     else:
         all_entities = [email.send_to]
     send_to = Subscription.objects.filter_not_subscribed(
